@@ -15,22 +15,20 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 from mpd.track import MidiEventStream
+import logging
+
 class Synth:
     NUM_CHANNELS = 16
     def __init__(self, verbose_init):
-        print "Solfege will use fakesynth"
+        logging.debug("Solfege will use fakesynth")
         self.m_type_major = "Fake"
     def close(self):
         pass
     def stop(self):
         pass
     def play_track(self, *tracks):
-        print "FakeSynth.play_track()"
-        last = None
+        logging.debug("FakeSynth.play_track()")
         for e in MidiEventStream(*tracks):
-            if e[0] != last:
-                print
-            print e,
-            last = e[0]
-        print
+            logging.debug(str(e))
+        logging.debug("")
 
