@@ -14,6 +14,13 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+if __name__ == '__main__':
+    import sys
+    sys.path.insert(0, ".")
+    import src
+    import src.i18n
+    src.i18n.setup(".")
+
 import gtk
 import history
 import utils
@@ -34,7 +41,6 @@ class DocViewer(gtk.VBox):
         self.m_htmlwidget = HtmlWidget(activate_cb, self.on_anchor_track)
         self.m_htmlwidget.show_all()
         self.pack_start(self.m_htmlwidget)
-        self.set_size_request(500, 300)
         self.get_vadjustment = self.m_htmlwidget.get_vadjustment
         self.on_key_press_event = self.m_htmlwidget.on_key_press_event
         self.m_statusbar = gtk.Statusbar()
@@ -111,7 +117,7 @@ class HelpBrowser(gtk.Window):
         self.add(self.vbox)
         self.vbox.pack_start(self.g_ui_manager.get_widget("/HelpToolbar"), False)
         #self.add_accel_group(self.g_ui_manager.get_accel_group())
-        self.set_default_size(550, 500)
+        self.set_default_size(650, 500)
         self.g_docviewer = DocViewer(self.handle_href)
         self.vbox.pack_start(self.g_docviewer)
         self.connect('delete_event', self.hide_on_delete)
@@ -183,13 +189,9 @@ class HelpBrowser(gtk.Window):
         self.g_docviewer.read_docfile(absname, anchor)
 
 if __name__ == '__main__':
-    import sys
-    sys.path.insert(0, ".")
-    import src
-    import src.i18n
-    src.i18n.setup(".")
-    w = HelpBrowser()
+    w = HelpBrowser(None)
     w.connect('delete_event', gtk.main_quit)
+    w.connect('destroy', gtk.main_quit)
     w.show()
-    w.show_docfile("toc.html")
+    w.show_docfile(sys.argv[1])
     gtk.main()
