@@ -279,7 +279,7 @@ class MainWin(gtk.Window):
                                     gtk.STOCK_OPEN, gtk.RESPONSE_OK))
         dialog.set_default_response(gtk.RESPONSE_OK)
         if dialog.run() == gtk.RESPONSE_OK:
-            filename = dialog.get_filename()
+            filename = gu.decode_filename(dialog.get_filename())
             try:
                 self.load_file(filename)
             except Exception, e:
@@ -307,7 +307,7 @@ class MainWin(gtk.Window):
         dialog.set_default_response(gtk.RESPONSE_OK)
 
         if dialog.run() == gtk.RESPONSE_OK:
-            self.m_P.m_filename = dialog.get_filename()
+            self.m_P.m_filename = gu.decode_filename(dialog.get_filename())
             self.save_file()
         dialog.destroy()
     def file_save_cb(self, *v):
@@ -320,7 +320,7 @@ class MainWin(gtk.Window):
             dialog.set_default_response(gtk.RESPONSE_OK)
 
             if dialog.run() == gtk.RESPONSE_OK:
-                self.m_P.m_filename = dialog.get_filename()
+                self.m_P.m_filename = gu.decode_filename(dialog.get_filename())
             dialog.destroy()
         if self.m_P.m_filename:
             self.update_appwin()
