@@ -15,6 +15,22 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+import logging
+import logging.handlers
+import optionparser
+
+opt_parser = optionparser.SolfegeOptionParser()
+options, args = opt_parser.parse_args()
+
+if options.debug:
+    handler = logging.StreamHandler()
+    logging.getLogger().addHandler(handler)
+    logging.getLogger().setLevel(logging.DEBUG)
+else:
+    handler = logging.handlers.MemoryHandler(1)
+    logging.getLogger().addHandler(handler)
+
+
 import webbrowser
 import textwrap
 # We move x-www-browser to the end of the list because on my
@@ -59,51 +75,6 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import osutils
 
-import optparse
-
-class MyOptionParser(optparse.OptionParser):
-    def print_help(self, outfile=None):
-        if outfile is None:
-            outfile = sys.stdout
-        encoding = outfile.encoding
-        if not encoding:
-            encoding = "iso-8859-1"
-        outfile.write(self.format_help().encode(encoding, 'replace'))
-
-opt_parser = MyOptionParser()
-opt_parser.add_option('-v', '--version', action='store_true', dest='version')
-opt_parser.add_option('-w', '--warranty', action='store_true', dest='warranty',
-    help=_('Show warranty and copyright.'))
-opt_parser.add_option('--no-splash', action='store_false', dest='no_splash',
-    help=_('Do not show the startup window.'),
-    default=False)
-opt_parser.add_option('--verbose-sound-init', action='store_true',
-    default=False,
-    dest='verbose_sound_init',
-    help=_('Display more info about the sound setup.'))
-opt_parser.add_option('--no-sound', action='store_true', dest='no_sound',
-    default=False,
-    help=_('Do not play any sounds. Instead some data is printed to standard output. Use this for debugging and porting.'))
-opt_parser.add_option('--debug', action='store_true', dest='debug',
-    help=_('Include features used by the Solfege developers to debug the program.'))
-opt_parser.add_option('--disable-exception-handler', action='store_true',
-    dest='disable_exception_handler',
-    help=_("Disable the exception handling in Gui.standard_exception_handler."))
-opt_parser.add_option('--no-random', action='store_true', dest='no_random',
-    help=_('For debugging only: Select questions from lesson files in sequential order.'))
-opt_parser.add_option('--enable-gtkhtml', action='store_true', 
-    dest='enable_gtkhtml',
-    help=_('Run using gtkhtml2 instead of the built in HTML viewer.'))
-opt_parser.add_option('--no-cairo-widgets', action='store_true',
-    dest='no_cairo_widgets',
-    help=_("Do not use the cairo version of input widgets, even if we run gtk+ 2.8.0 or newer."))
-opt_parser.add_option('--show-gtk-warnings', action='store_true',
-    dest='show_gtk_warnings',
-    help=_('Show GtkWarnings and PangoWarnings in the traceback window.'))
-
-
-options, args = opt_parser.parse_args()
-
 if options.version:
     if buildinfo.is_release():
         rev_info = ""
@@ -700,7 +671,7 @@ class MainWin(gtk.Window, cfg.ConfigUtils):
             os.path.exists(os.path.join(filesystem.app_data(),
                                         "learningtrees"))):
             if not os.path.exists(os.path.join(filesystem.user_data(), "learningtrees")):
-                os.mkdir(os.path.join(filesystem.user_data(), "learningtrees"))
+                os.makedirs(os.path.join(filesystem.user_data(), "learningtrees"))
             for fn in os.listdir(os.path.join(filesystem.app_data(), "learningtrees")):
                 if not os.path.exists(os.path.join(filesystem.user_data(), "learningtrees", fn)):
                     shutil.move(os.path.join(filesystem.app_data(), "learningtrees", fn),
