@@ -14,9 +14,12 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import sys
+sys.path.insert(0, ".")
 from src import buildinfo
 from src._version import version_info
+from textwrap import wrap
 
 if version_info['revision_id'] != buildinfo.REVISION_ID:
+    print "\n", "\n".join(wrap("Set the revision-id in configure.ac, run autoconf and ./configure before re-running the test.")), "\n"
     sys.exit(1)
 sys.exit(0)
